# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.ssf_api import SsfApi


class TestSsfApi(unittest.TestCase):
    """SsfApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SsfApi()

    def tearDown(self) -> None:
        pass

    def test_ssf_streams_list(self) -> None:
        """Test case for ssf_streams_list

        """
        pass

    def test_ssf_streams_retrieve(self) -> None:
        """Test case for ssf_streams_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
